@@ -230,16 +230,15 @@ int main(int argc, char *argv[])
     int do_fork = 1;
 
     halevt_fork = 0;
+    halevt_report = 0;
 
     setlocale (LC_ALL, "");
     bindtextdomain (PACKAGE, DATADIR "/locale/");
     textdomain (PACKAGE);
 
-    DEBUG("%s, http://www.environnement.ens.fr/perso/dumas/halevt.html", PACKAGE_STRING);
-
     while (1)
     {
-        c = getopt(argc, argv, "c:u:g:fp:h");
+        c = getopt(argc, argv, "ic:u:g:fp:h");
         if (c == -1) { break ; }
         switch (c) 
         {
@@ -261,6 +260,10 @@ int main(int argc, char *argv[])
                }
                conffiles[1] = NULL;
                break;
+            case 'i':
+               halevt_report = 1;
+               do_fork = 0;
+               break;
             case 'u':
                if ((user = strdup(optarg)) == NULL)
                {
@@ -325,26 +328,32 @@ int main(int argc, char *argv[])
         }
     }
 
-    /* parse conf file */
-    if (conffiles == NULL) { conffiles = halevt_find_conf_files (); }
-    if (conffiles[0] == NULL)
+    if (halevt_report == 0)
     {
-        DEBUG(_("No configuration file found"));
-        exit (1);
-    }
-    current_conffile = conffiles;
-    while (*current_conffile != NULL)
-    {
-        if (! halevt_parse_config (*current_conffile))
+       /* parse conf file */
+        if (conffiles == NULL) { conffiles = halevt_find_conf_files (); }
+        if (conffiles[0] == NULL)
         {
-           DEBUG(_("Configuration file %s parsing failed"), *current_conffile);
-           exit(1);
+            DEBUG(_("No configuration file found"));
+            exit (1);
         }
-        DEBUG(_("Using configuration file %s"), *current_conffile);
-        free (*current_conffile);
-        current_conffile++;
+        current_conffile = conffiles;
+        while (*current_conffile != NULL)
+        {
+            if (! halevt_parse_config (*current_conffile))
+            {
+                DEBUG(_("Configuration file %s parsing failed"), *current_conffile);
+                exit(1);
+            }
+            if (halevt_fork)
+            {
+                DEBUG(_("Using configuration file %s"), *current_conffile);
+            }
+            free (*current_conffile);
+            current_conffile++;
+        }
+        free (conffiles);
     }
-    free (conffiles);
 
     /* halevt_print_config(); */
     halevt_setup_HAL();
@@ -359,6 +368,8 @@ int main(int argc, char *argv[])
 
         halevt_fork = 1;
 
+        DEBUG("%s, http://www.environnement.ens.fr/perso/dumas/halevt.html", PACKAGE_STRING);
+
         if (pid_file == NULL)
         {
             DEBUG(_("No pid file used"));
@@ -398,9 +409,13 @@ int main(int argc, char *argv[])
     signal(SIGINT, halevt_signal_handler);
     signal(SIGHUP, halevt_signal_handler);
 
-    DEBUG(_("Entering main loop."));
+/*    
+    DEBUG(_("Entering main loop.")); 
+*/
     g_main_loop_run(loop);
-    DEBUG(_("Exiting normally."));
+/*    
+    DEBUG(_("Exiting normally.")); 
+*/
 
     if (halevt_fork) { halevt_clear_pidfile(pid_file); }
 
